@@ -65,9 +65,7 @@ get '/search' => sub {
 
     if (not param('tab')) {
         if (not $q) {
-            status(302);
-            header(Location => uri_for('/')->path_query());
-            return;
+            return redirect uri_for('/')->as_string;
         }
 
         # pick most likely tab for initial results
@@ -75,18 +73,16 @@ get '/search' => sub {
             params->{'tab'} = 'vlan';
         }
         else {
-            my $nd = $s->resultset('Device')->search_aliases($q);
+            my $nd = $s->resultset('Device')->search_fuzzy($q);
 
             if ($nd and $nd->count) {
                 if ($nd->count == 1) {
                     # redirect to device details for the one device
-                    status(302);
-                    header(Location => uri_for('/device', {
+                    return redirect uri_for('/device', {
                       tab => 'details',
                       q => ($nd->first->dns || $nd->first->ip),
                       f => '',
-                    })->path_query());
-                    return;
+                    })->as_string;
                 }
 
                 # multiple devices
