@@ -173,7 +173,7 @@ $(document).ready(function() {
   // activate typeahead on the main search box, for device names only
   $('#nq').typeahead({
     source: function (query, process) {
-      return $.get('/ajax/data/devicename/typeahead', { query: query }, function (data) {
+      return $.get( uri_base + '/ajax/data/devicename/typeahead', { query: query }, function (data) {
         return process(data);
       });
     }
